import React from 'react';
import type { Metadata } from 'next';
import { draftMode } from 'next/headers'
import {unstable_setRequestLocale} from "next-intl/server";
import Link from "next/link";
import {fetchBlogPosts} from "../../../../../lib/contentful/blogPosts";
import {fetchBlogPostCategories} from "../../../../../lib/contentful/blogPostsCategories";

export const metadata: Metadata = {
    title: 'Bbuddy - Blog',
    description: 'Bbuddy desc blog'
};

interface BlogPostPageParams {
    slug: string
    locale: string
}
interface BlogPostPageProps {
    params: BlogPostPageParams
}

export default async function Blog({params}: { params: BlogPostPageParams }) {
    unstable_setRequestLocale(params.locale);
    const data = await fetchBlogPosts({ preview: draftMode().isEnabled, locale: params.locale, category: params.slug })
    const cats = await fetchBlogPostCategories(false)
    return (
        <div className="b-news">
            <div className="b-news__header">
                <div className="b-inner">
                    <h1 className="title-h1">
                        Mentorship, Career <br/>
                        Development & Coaching.
                    </h1>
                    <div className="wrap-text">
                        <p className="">The ins-and-outs of building a career in tech, gaining <br/> experience</p>
                        <p className="">from a mentor, and getting your feet wet with coaching.</p>
                    </div>
                    <div className="b-news__header__img">
                        <img className="" src="/images/news-top.png" alt=""/>
                    </div>
                </div>
            </div>
            <div className="b-news__filter ">
                <div className="b-inner">
                    <div className="wrap-filter">
                        {
                            cats.map((cat, i)=>(
                                <Link key={'blogCat'+i} href={'/'+params.locale+'/blog/category/'+cat.slug} className={"filter-item"+(cat.slug === params.slug ? ' active' : '')}>{cat.title}</Link>
                            ))
                        }
                    </div>
                </div>
            </div>
            <div className="b-news__result-list">
                <div className="b-inner">
                    <div className="news-list">
                        {data.map((item, i) => (
                            <li key={'blogPost'+i} className="list-sidebar__item">
                                <Link href={'/'+params.locale+'/blog/'+item.slug} className="news-item">
                                    <div className="news-item__image">
                                        <img className="" src={item.listImage?.src} alt={item.listImage?.alt}/>
                                    </div>
                                    <div className="news-item__inner">
                                        <div className="">
                                            <div className="news-item__title">
                                                {item.title}
                                            </div>
                                            <div className="news-item__badge">{item.category}</div>
                                            <div className="news-item__text">
                                                {item.excerpt}
                                            </div>
                                        </div>
                                        <div className="news-item__info">
                                            <div className="news-item__info__author">
                                                <img className="" src={item.author.avatar.src} alt=""/>
                                                <div className="news-item__info__author__inner">
                                                    <div className="news-item__info__name">{item.author.name}</div>
                                                    <div className="news-item__info__date">{item.createdAt}</div>
                                                </div>
                                            </div>
                                            <div className="news-item__info__counter">
                                                <div className="news-item__info__like">
                                                    <img className="" src="/images/heart-outline.svg" alt=""/>
                                                    165
                                                </div>
                                                <div className="news-item__info__share">
                                                    <img className="" src="/images/share-social.svg" alt=""/>
                                                    Share
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </Link>
                            </li>
                        ))}
                    </div>
                </div>
            </div>
        </div>
    );
}
